==> infima_client-0.186.0-py3-none-any.whl: infima_client/models/search_service_search_json_body_attributes.py <==
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.search_service_search_json_body_attributes_coupon_range import (
    SearchService_SearchJsonBodyAttributesCouponRange,
)
from ..models.search_service_search_json_body_attributes_investor_occ_range import (
    SearchService_SearchJsonBodyAttributesInvestorOccRange,
)
from ..models.search_service_search_json_body_attributes_iss_upb_range import (
    SearchService_SearchJsonBodyAttributesIssUpbRange,
)
from ..models.search_service_search_json_body_attributes_issue_date_range import (
    SearchService_SearchJsonBodyAttributesIssueDateRange,
)
from ..models.search_service_search_json_body_attributes_maturity_date_range import (
    SearchService_SearchJsonBodyAttributesMaturityDateRange,
)
from ..models.search_service_search_json_body_attributes_max_cs_range import (
    SearchService_SearchJsonBodyAttributesMaxCsRange,
)
from ..models.search_service_search_json_body_attributes_max_iss_loan_balance_range import (
    SearchService_SearchJsonBodyAttributesMaxIssLoanBalanceRange,
)
from ..models.search_service_search_json_body_attributes_min_cs_range import (
    SearchService_SearchJsonBodyAttributesMinCsRange,
)
from ..models.search_service_search_json_body_attributes_min_iss_loan_balance_range import (
    SearchService_SearchJsonBodyAttributesMinIssLoanBalanceRange,
)
from ..models.search_service_search_json_body_attributes_upb_range import (
    SearchService_SearchJsonBodyAttributesUpbRange,
)
from ..models.search_service_search_json_body_attributes_wac_range import (
    SearchService_SearchJsonBodyAttributesWacRange,
)
from ..models.search_service_search_json_body_attributes_waocs_range import (
    SearchService_SearchJsonBodyAttributesWaocsRange,
)
from ..models.search_service_search_json_body_attributes_waols_range import (
    SearchService_SearchJsonBodyAttributesWaolsRange,
)
from ..models.search_service_search_json_body_attributes_waoltv_range import (
    SearchService_SearchJsonBodyAttributesWaoltvRange,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="SearchService_SearchJsonBodyAttributes")


@attr.s(auto_attribs=True)
class SearchService_SearchJsonBodyAttributes:
    """  """

    coupon_range: Union[
        SearchService_SearchJsonBodyAttributesCouponRange, Unset
    ] = UNSET
    investor_occ_range: Union[
        SearchService_SearchJsonBodyAttributesInvestorOccRange, Unset
    ] = UNSET
    iss_upb_range: Union[
        SearchService_SearchJsonBodyAttributesIssUpbRange, Unset
    ] = UNSET
    issue_date_range: Union[
        SearchService_SearchJsonBodyAttributesIssueDateRange, Unset
    ] = UNSET
    maturity_date_range: Union[
        SearchService_SearchJsonBodyAttributesMaturityDateRange, Unset
    ] = UNSET
    max_cs_range: Union[SearchService_SearchJsonBodyAttributesMaxCsRange, Unset] = UNSET
    max_iss_loan_balance_range: Union[
        SearchService_SearchJsonBodyAttributesMaxIssLoanBalanceRange, Unset
    ] = UNSET
    min_cs_range: Union[SearchService_SearchJsonBodyAttributesMinCsRange, Unset] = UNSET
    min_iss_loan_balance_range: Union[
        SearchService_SearchJsonBodyAttributesMinIssLoanBalanceRange, Unset
    ] = UNSET
    upb_range: Union[SearchService_SearchJsonBodyAttributesUpbRange, Unset] = UNSET
    wac_range: Union[SearchService_SearchJsonBodyAttributesWacRange, Unset] = UNSET
    waocs_range: Union[SearchService_SearchJsonBodyAttributesWaocsRange, Unset] = UNSET
    waols_range: Union[SearchService_SearchJsonBodyAttributesWaolsRange, Unset] = UNSET
    waoltv_range: Union[
        SearchService_SearchJsonBodyAttributesWaoltvRange, Unset
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        coupon_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.coupon_range, Unset):
            coupon_range = self.coupon_range.to_dict()

        investor_occ_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.investor_occ_range, Unset):
            investor_occ_range = self.investor_occ_range.to_dict()

        iss_upb_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.iss_upb_range, Unset):
            iss_upb_range = self.iss_upb_range.to_dict()

        issue_date_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.issue_date_range, Unset):
            issue_date_range = self.issue_date_range.to_dict()

        maturity_date_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.maturity_date_range, Unset):
            maturity_date_range = self.maturity_date_range.to_dict()

        max_cs_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.max_cs_range, Unset):
            max_cs_range = self.max_cs_range.to_dict()

        max_iss_loan_balance_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.max_iss_loan_balance_range, Unset):
            max_iss_loan_balance_range = self.max_iss_loan_balance_range.to_dict()

        min_cs_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.min_cs_range, Unset):
            min_cs_range = self.min_cs_range.to_dict()

        min_iss_loan_balance_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.min_iss_loan_balance_range, Unset):
            min_iss_loan_balance_range = self.min_iss_loan_balance_range.to_dict()

        upb_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.upb_range, Unset):
            upb_range = self.upb_range.to_dict()

        wac_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.wac_range, Unset):
            wac_range = self.wac_range.to_dict()

        waocs_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.waocs_range, Unset):
            waocs_range = self.waocs_range.to_dict()

        waols_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.waols_range, Unset):
            waols_range = self.waols_range.to_dict()

        waoltv_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.waoltv_range, Unset):
            waoltv_range = self.waoltv_range.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if coupon_range is not UNSET:
            field_dict["couponRange"] = coupon_range
        if investor_occ_range is not UNSET:
            field_dict["investorOccRange"] = investor_occ_range
        if iss_upb_range is not UNSET:
            field_dict["issUpbRange"] = iss_upb_range
        if issue_date_range is not UNSET:
            field_dict["issueDateRange"] = issue_date_range
        if maturity_date_range is not UNSET:
            field_dict["maturityDateRange"] = maturity_date_range
        if max_cs_range is not UNSET:
            field_dict["maxCsRange"] = max_cs_range
        if max_iss_loan_balance_range is not UNSET:
            field_dict["maxIssLoanBalanceRange"] = max_iss_loan_balance_range
        if min_cs_range is not UNSET:
            field_dict["minCsRange"] = min_cs_range
        if min_iss_loan_balance_range is not UNSET:
            field_dict["minIssLoanBalanceRange"] = min_iss_loan_balance_range
        if upb_range is not UNSET:
            field_dict["upbRange"] = upb_range
        if wac_range is not UNSET:
            field_dict["wacRange"] = wac_range
        if waocs_range is not UNSET:
            field_dict["waocsRange"] = waocs_range
        if waols_range is not UNSET:
            field_dict["waolsRange"] = waols_range
        if waoltv_range is not UNSET:
            field_dict["waoltvRange"] = waoltv_range

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        coupon_range: Union[
            SearchService_SearchJsonBodyAttributesCouponRange, Unset
        ] = UNSET
        _coupon_range = d.pop("couponRange", UNSET)
        if not isinstance(_coupon_range, Unset):
            coupon_range = SearchService_SearchJsonBodyAttributesCouponRange.from_dict(
                cast(Dict[str, Any], _coupon_range)
            )

        investor_occ_range: Union[
            SearchService_SearchJsonBodyAttributesInvestorOccRange, Unset
        ] = UNSET
        _investor_occ_range = d.pop("investorOccRange", UNSET)
        if not isinstance(_investor_occ_range, Unset):
            investor_occ_range = (
                SearchService_SearchJsonBodyAttributesInvestorOccRange.from_dict(
                    cast(Dict[str, Any], _investor_occ_range)
                )
            )

        iss_upb_range: Union[
            SearchService_SearchJsonBodyAttributesIssUpbRange, Unset
        ] = UNSET
        _iss_upb_range = d.pop("issUpbRange", UNSET)
        if not isinstance(_iss_upb_range, Unset):
            iss_upb_range = SearchService_SearchJsonBodyAttributesIssUpbRange.from_dict(
                cast(Dict[str, Any], _iss_upb_range)
            )

        issue_date_range: Union[
            SearchService_SearchJsonBodyAttributesIssueDateRange, Unset
        ] = UNSET
        _issue_date_range = d.pop("issueDateRange", UNSET)
        if not isinstance(_issue_date_range, Unset):
            issue_date_range = (
                SearchService_SearchJsonBodyAttributesIssueDateRange.from_dict(
                    cast(Dict[str, Any], _issue_date_range)
                )
            )

        maturity_date_range: Union[
            SearchService_SearchJsonBodyAttributesMaturityDateRange, Unset
        ] = UNSET
        _maturity_date_range = d.pop("maturityDateRange", UNSET)
        if not isinstance(_maturity_date_range, Unset):
            maturity_date_range = (
                SearchService_SearchJsonBodyAttributesMaturityDateRange.from_dict(
                    cast(Dict[str, Any], _maturity_date_range)
                )
            )

        max_cs_range: Union[
            SearchService_SearchJsonBodyAttributesMaxCsRange, Unset
        ] = UNSET
        _max_cs_range = d.pop("maxCsRange", UNSET)
        if not isinstance(_max_cs_range, Unset):
            max_cs_range = SearchService_SearchJsonBodyAttributesMaxCsRange.from_dict(
                cast(Dict[str, Any], _max_cs_range)
            )

        max_iss_loan_balance_range: Union[
            SearchService_SearchJsonBodyAttributesMaxIssLoanBalanceRange, Unset
        ] = UNSET
        _max_iss_loan_balance_range = d.pop("maxIssLoanBalanceRange", UNSET)
        if not isinstance(_max_iss_loan_balance_range, Unset):
            max_iss_loan_balance_range = (
                SearchService_SearchJsonBodyAttributesMaxIssLoanBalanceRange.from_dict(
                    cast(Dict[str, Any], _max_iss_loan_balance_range)
                )
            )

        min_cs_range: Union[
            SearchService_SearchJsonBodyAttributesMinCsRange, Unset
        ] = UNSET
        _min_cs_range = d.pop("minCsRange", UNSET)
        if not isinstance(_min_cs_range, Unset):
            min_cs_range = SearchService_SearchJsonBodyAttributesMinCsRange.from_dict(
                cast(Dict[str, Any], _min_cs_range)
            )

        min_iss_loan_balance_range: Union[
            SearchService_SearchJsonBodyAttributesMinIssLoanBalanceRange, Unset
        ] = UNSET
        _min_iss_loan_balance_range = d.pop("minIssLoanBalanceRange", UNSET)
        if not isinstance(_min_iss_loan_balance_range, Unset):
            min_iss_loan_balance_range = (
                SearchService_SearchJsonBodyAttributesMinIssLoanBalanceRange.from_dict(
                    cast(Dict[str, Any], _min_iss_loan_balance_range)
                )
            )

        upb_range: Union[SearchService_SearchJsonBodyAttributesUpbRange, Unset] = UNSET
        _upb_range = d.pop("upbRange", UNSET)
        if not isinstance(_upb_range, Unset):
            upb_range = SearchService_SearchJsonBodyAttributesUpbRange.from_dict(
                cast(Dict[str, Any], _upb_range)
            )

        wac_range: Union[SearchService_SearchJsonBodyAttributesWacRange, Unset] = UNSET
        _wac_range = d.pop("wacRange", UNSET)
        if not isinstance(_wac_range, Unset):
            wac_range = SearchService_SearchJsonBodyAttributesWacRange.from_dict(
                cast(Dict[str, Any], _wac_range)
            )

        waocs_range: Union[
            SearchService_SearchJsonBodyAttributesWaocsRange, Unset
        ] = UNSET
        _waocs_range = d.pop("waocsRange", UNSET)
        if not isinstance(_waocs_range, Unset):
            waocs_range = SearchService_SearchJsonBodyAttributesWaocsRange.from_dict(
                cast(Dict[str, Any], _waocs_range)
            )

        waols_range: Union[
            SearchService_SearchJsonBodyAttributesWaolsRange, Unset
        ] = UNSET
        _waols_range = d.pop("waolsRange", UNSET)
        if not isinstance(_waols_range, Unset):
            waols_range = SearchService_SearchJsonBodyAttributesWaolsRange.from_dict(
                cast(Dict[str, Any], _waols_range)
            )

        waoltv_range: Union[
            SearchService_SearchJsonBodyAttributesWaoltvRange, Unset
        ] = UNSET
        _waoltv_range = d.pop("waoltvRange", UNSET)
        if not isinstance(_waoltv_range, Unset):
            waoltv_range = SearchService_SearchJsonBodyAttributesWaoltvRange.from_dict(
                cast(Dict[str, Any], _waoltv_range)
            )

        search_service_search_json_body_attributes = cls(
            coupon_range=coupon_range,
            investor_occ_range=investor_occ_range,
            iss_upb_range=iss_upb_range,
            issue_date_range=issue_date_range,
            maturity_date_range=maturity_date_range,
            max_cs_range=max_cs_range,
            max_iss_loan_balance_range=max_iss_loan_balance_range,
            min_cs_range=min_cs_range,
            min_iss_loan_balance_range=min_iss_loan_balance_range,
            upb_range=upb_range,
            wac_range=wac_range,
            waocs_range=waocs_range,
            waols_range=waols_range,
            waoltv_range=waoltv_range,
        )

        search_service_search_json_body_attributes.additional_properties = d
        return search_service_search_json_body_attributes

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> infima_client-0.259.0-py3-none-any.whl: infima_client/models/search_service_search_json_body_attributes.py <==
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.search_service_search_json_body_attributes_basedon_pools_stream import (
    SearchService_SearchJsonBodyAttributesBasedonPoolsStream,
)
from ..models.search_service_search_json_body_attributes_basedon_pools_summaries import (
    SearchService_SearchJsonBodyAttributesBasedonPoolsSummaries,
)
from ..models.search_service_search_json_body_attributes_cpr_range import (
    SearchService_SearchJsonBodyAttributesCprRange,
)
from ..models.search_service_search_json_body_attributes_iss_upb_range import (
    SearchService_SearchJsonBodyAttributesIssUpbRange,
)
from ..models.search_service_search_json_body_attributes_issue_date_range import (
    SearchService_SearchJsonBodyAttributesIssueDateRange,
)
from ..models.search_service_search_json_body_attributes_maturity_date_range import (
    SearchService_SearchJsonBodyAttributesMaturityDateRange,
)
from ..models.search_service_search_json_body_attributes_max_cs_range import (
    SearchService_SearchJsonBodyAttributesMaxCsRange,
)
from ..models.search_service_search_json_body_attributes_max_iss_loan_balance_range import (
    SearchService_SearchJsonBodyAttributesMaxIssLoanBalanceRange,
)
from ..models.search_service_search_json_body_attributes_min_cs_range import (
    SearchService_SearchJsonBodyAttributesMinCsRange,
)
from ..models.search_service_search_json_body_attributes_min_iss_loan_balance_range import (
    SearchService_SearchJsonBodyAttributesMinIssLoanBalanceRange,
)
from ..models.search_service_search_json_body_attributes_upb_range import (
    SearchService_SearchJsonBodyAttributesUpbRange,
)
from ..models.search_service_search_json_body_attributes_wac_range import (
    SearchService_SearchJsonBodyAttributesWacRange,
)
from ..models.search_service_search_json_body_attributes_waocs_range import (
    SearchService_SearchJsonBodyAttributesWaocsRange,
)
from ..models.search_service_search_json_body_attributes_waols_range import (
    SearchService_SearchJsonBodyAttributesWaolsRange,
)
from ..models.search_service_search_json_body_attributes_waoltv_range import (
    SearchService_SearchJsonBodyAttributesWaoltvRange,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="SearchService_SearchJsonBodyAttributes")


@attr.s(auto_attribs=True)
class SearchService_SearchJsonBodyAttributes:
    """  """

    coupon_range: Union[
        SearchService_SearchJsonBodyAttributesBasedonPoolsStream, Unset
    ] = UNSET
    cpr_range: Union[SearchService_SearchJsonBodyAttributesCprRange, Unset] = UNSET
    investor_occ_range: Union[
        SearchService_SearchJsonBodyAttributesBasedonPoolsSummaries, Unset
    ] = UNSET
    iss_upb_range: Union[
        SearchService_SearchJsonBodyAttributesIssUpbRange, Unset
    ] = UNSET
    issue_date_range: Union[
        SearchService_SearchJsonBodyAttributesIssueDateRange, Unset
    ] = UNSET
    maturity_date_range: Union[
        SearchService_SearchJsonBodyAttributesMaturityDateRange, Unset
    ] = UNSET
    max_cs_range: Union[SearchService_SearchJsonBodyAttributesMaxCsRange, Unset] = UNSET
    max_iss_loan_balance_range: Union[
        SearchService_SearchJsonBodyAttributesMaxIssLoanBalanceRange, Unset
    ] = UNSET
    min_cs_range: Union[SearchService_SearchJsonBodyAttributesMinCsRange, Unset] = UNSET
    min_iss_loan_balance_range: Union[
        SearchService_SearchJsonBodyAttributesMinIssLoanBalanceRange, Unset
    ] = UNSET
    upb_range: Union[SearchService_SearchJsonBodyAttributesUpbRange, Unset] = UNSET
    wac_range: Union[SearchService_SearchJsonBodyAttributesWacRange, Unset] = UNSET
    waocs_range: Union[SearchService_SearchJsonBodyAttributesWaocsRange, Unset] = UNSET
    waols_range: Union[SearchService_SearchJsonBodyAttributesWaolsRange, Unset] = UNSET
    waoltv_range: Union[
        SearchService_SearchJsonBodyAttributesWaoltvRange, Unset
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        coupon_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.coupon_range, Unset):
            coupon_range = self.coupon_range.to_dict()

        cpr_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.cpr_range, Unset):
            cpr_range = self.cpr_range.to_dict()

        investor_occ_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.investor_occ_range, Unset):
            investor_occ_range = self.investor_occ_range.to_dict()

        iss_upb_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.iss_upb_range, Unset):
            iss_upb_range = self.iss_upb_range.to_dict()

        issue_date_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.issue_date_range, Unset):
            issue_date_range = self.issue_date_range.to_dict()

        maturity_date_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.maturity_date_range, Unset):
            maturity_date_range = self.maturity_date_range.to_dict()

        max_cs_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.max_cs_range, Unset):
            max_cs_range = self.max_cs_range.to_dict()

        max_iss_loan_balance_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.max_iss_loan_balance_range, Unset):
            max_iss_loan_balance_range = self.max_iss_loan_balance_range.to_dict()

        min_cs_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.min_cs_range, Unset):
            min_cs_range = self.min_cs_range.to_dict()

        min_iss_loan_balance_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.min_iss_loan_balance_range, Unset):
            min_iss_loan_balance_range = self.min_iss_loan_balance_range.to_dict()

        upb_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.upb_range, Unset):
            upb_range = self.upb_range.to_dict()

        wac_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.wac_range, Unset):
            wac_range = self.wac_range.to_dict()

        waocs_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.waocs_range, Unset):
            waocs_range = self.waocs_range.to_dict()

        waols_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.waols_range, Unset):
            waols_range = self.waols_range.to_dict()

        waoltv_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.waoltv_range, Unset):
            waoltv_range = self.waoltv_range.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if coupon_range is not UNSET:
            field_dict["couponRange"] = coupon_range
        if cpr_range is not UNSET:
            field_dict["cprRange"] = cpr_range
        if investor_occ_range is not UNSET:
            field_dict["investorOccRange"] = investor_occ_range
        if iss_upb_range is not UNSET:
            field_dict["issUpbRange"] = iss_upb_range
        if issue_date_range is not UNSET:
            field_dict["issueDateRange"] = issue_date_range
        if maturity_date_range is not UNSET:
            field_dict["maturityDateRange"] = maturity_date_range
        if max_cs_range is not UNSET:
            field_dict["maxCsRange"] = max_cs_range
        if max_iss_loan_balance_range is not UNSET:
            field_dict["maxIssLoanBalanceRange"] = max_iss_loan_balance_range
        if min_cs_range is not UNSET:
            field_dict["minCsRange"] = min_cs_range
        if min_iss_loan_balance_range is not UNSET:
            field_dict["minIssLoanBalanceRange"] = min_iss_loan_balance_range
        if upb_range is not UNSET:
            field_dict["upbRange"] = upb_range
        if wac_range is not UNSET:
            field_dict["wacRange"] = wac_range
        if waocs_range is not UNSET:
            field_dict["waocsRange"] = waocs_range
        if waols_range is not UNSET:
            field_dict["waolsRange"] = waols_range
        if waoltv_range is not UNSET:
            field_dict["waoltvRange"] = waoltv_range

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        coupon_range: Union[
            SearchService_SearchJsonBodyAttributesBasedonPoolsStream, Unset
        ] = UNSET
        _coupon_range = d.pop("couponRange", UNSET)
        if not isinstance(_coupon_range, Unset):
            coupon_range = (
                SearchService_SearchJsonBodyAttributesBasedonPoolsStream.from_dict(
                    cast(Dict[str, Any], _coupon_range)
                )
            )

        cpr_range: Union[SearchService_SearchJsonBodyAttributesCprRange, Unset] = UNSET
        _cpr_range = d.pop("cprRange", UNSET)
        if not isinstance(_cpr_range, Unset):
            cpr_range = SearchService_SearchJsonBodyAttributesCprRange.from_dict(
                cast(Dict[str, Any], _cpr_range)
            )

        investor_occ_range: Union[
            SearchService_SearchJsonBodyAttributesBasedonPoolsSummaries, Unset
        ] = UNSET
        _investor_occ_range = d.pop("investorOccRange", UNSET)
        if not isinstance(_investor_occ_range, Unset):
            investor_occ_range = (
                SearchService_SearchJsonBodyAttributesBasedonPoolsSummaries.from_dict(
                    cast(Dict[str, Any], _investor_occ_range)
                )
            )

        iss_upb_range: Union[
            SearchService_SearchJsonBodyAttributesIssUpbRange, Unset
        ] = UNSET
        _iss_upb_range = d.pop("issUpbRange", UNSET)
        if not isinstance(_iss_upb_range, Unset):
            iss_upb_range = SearchService_SearchJsonBodyAttributesIssUpbRange.from_dict(
                cast(Dict[str, Any], _iss_upb_range)
            )

        issue_date_range: Union[
            SearchService_SearchJsonBodyAttributesIssueDateRange, Unset
        ] = UNSET
        _issue_date_range = d.pop("issueDateRange", UNSET)
        if not isinstance(_issue_date_range, Unset):
            issue_date_range = (
                SearchService_SearchJsonBodyAttributesIssueDateRange.from_dict(
                    cast(Dict[str, Any], _issue_date_range)
                )
            )

        maturity_date_range: Union[
            SearchService_SearchJsonBodyAttributesMaturityDateRange, Unset
        ] = UNSET
        _maturity_date_range = d.pop("maturityDateRange", UNSET)
        if not isinstance(_maturity_date_range, Unset):
            maturity_date_range = (
                SearchService_SearchJsonBodyAttributesMaturityDateRange.from_dict(
                    cast(Dict[str, Any], _maturity_date_range)
                )
            )

        max_cs_range: Union[
            SearchService_SearchJsonBodyAttributesMaxCsRange, Unset
        ] = UNSET
        _max_cs_range = d.pop("maxCsRange", UNSET)
        if not isinstance(_max_cs_range, Unset):
            max_cs_range = SearchService_SearchJsonBodyAttributesMaxCsRange.from_dict(
                cast(Dict[str, Any], _max_cs_range)
            )

        max_iss_loan_balance_range: Union[
            SearchService_SearchJsonBodyAttributesMaxIssLoanBalanceRange, Unset
        ] = UNSET
        _max_iss_loan_balance_range = d.pop("maxIssLoanBalanceRange", UNSET)
        if not isinstance(_max_iss_loan_balance_range, Unset):
            max_iss_loan_balance_range = (
                SearchService_SearchJsonBodyAttributesMaxIssLoanBalanceRange.from_dict(
                    cast(Dict[str, Any], _max_iss_loan_balance_range)
                )
            )

        min_cs_range: Union[
            SearchService_SearchJsonBodyAttributesMinCsRange, Unset
        ] = UNSET
        _min_cs_range = d.pop("minCsRange", UNSET)
        if not isinstance(_min_cs_range, Unset):
            min_cs_range = SearchService_SearchJsonBodyAttributesMinCsRange.from_dict(
                cast(Dict[str, Any], _min_cs_range)
            )

        min_iss_loan_balance_range: Union[
            SearchService_SearchJsonBodyAttributesMinIssLoanBalanceRange, Unset
        ] = UNSET
        _min_iss_loan_balance_range = d.pop("minIssLoanBalanceRange", UNSET)
        if not isinstance(_min_iss_loan_balance_range, Unset):
            min_iss_loan_balance_range = (
                SearchService_SearchJsonBodyAttributesMinIssLoanBalanceRange.from_dict(
                    cast(Dict[str, Any], _min_iss_loan_balance_range)
                )
            )

        upb_range: Union[SearchService_SearchJsonBodyAttributesUpbRange, Unset] = UNSET
        _upb_range = d.pop("upbRange", UNSET)
        if not isinstance(_upb_range, Unset):
            upb_range = SearchService_SearchJsonBodyAttributesUpbRange.from_dict(
                cast(Dict[str, Any], _upb_range)
            )

        wac_range: Union[SearchService_SearchJsonBodyAttributesWacRange, Unset] = UNSET
        _wac_range = d.pop("wacRange", UNSET)
        if not isinstance(_wac_range, Unset):
            wac_range = SearchService_SearchJsonBodyAttributesWacRange.from_dict(
                cast(Dict[str, Any], _wac_range)
            )

        waocs_range: Union[
            SearchService_SearchJsonBodyAttributesWaocsRange, Unset
        ] = UNSET
        _waocs_range = d.pop("waocsRange", UNSET)
        if not isinstance(_waocs_range, Unset):
            waocs_range = SearchService_SearchJsonBodyAttributesWaocsRange.from_dict(
                cast(Dict[str, Any], _waocs_range)
            )

        waols_range: Union[
            SearchService_SearchJsonBodyAttributesWaolsRange, Unset
        ] = UNSET
        _waols_range = d.pop("waolsRange", UNSET)
        if not isinstance(_waols_range, Unset):
            waols_range = SearchService_SearchJsonBodyAttributesWaolsRange.from_dict(
                cast(Dict[str, Any], _waols_range)
            )

        waoltv_range: Union[
            SearchService_SearchJsonBodyAttributesWaoltvRange, Unset
        ] = UNSET
        _waoltv_range = d.pop("waoltvRange", UNSET)
        if not isinstance(_waoltv_range, Unset):
            waoltv_range = SearchService_SearchJsonBodyAttributesWaoltvRange.from_dict(
                cast(Dict[str, Any], _waoltv_range)
            )

        search_service_search_json_body_attributes = cls(
            coupon_range=coupon_range,
            cpr_range=cpr_range,
            investor_occ_range=investor_occ_range,
            iss_upb_range=iss_upb_range,
            issue_date_range=issue_date_range,
            maturity_date_range=maturity_date_range,
            max_cs_range=max_cs_range,
            max_iss_loan_balance_range=max_iss_loan_balance_range,
            min_cs_range=min_cs_range,
            min_iss_loan_balance_range=min_iss_loan_balance_range,
            upb_range=upb_range,
            wac_range=wac_range,
            waocs_range=waocs_range,
            waols_range=waols_range,
            waoltv_range=waoltv_range,
        )

        search_service_search_json_body_attributes.additional_properties = d
        return search_service_search_json_body_attributes

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
